emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] master b28a4a7 1/2: Fix the values possible for status queries in


From: Michael Albinus
Subject: [elpa] master b28a4a7 1/2: Fix the values possible for status queries in debbugs
Date: Wed, 22 Jun 2016 16:27:03 +0000 (UTC)

branch: master
commit b28a4a7613b7a873a05ef332782549acf1860899
Author: Michael Albinus <address@hidden>
Commit: Michael Albinus <address@hidden>

    Fix the values possible for status queries in debbugs
    
    * packages/debbugs/debbugs.el (debbugs-get-bugs)
    (debbugs-search-est):
    * packages/debbugs/debbugs-gnu.el (debbugs-gnu-search):
    * packages/debbugs/debbugs.texi (Requesting bug numbers)
    (Requesting bugs statuses):
    * packages/debbugs/debbugs-ug.texi (Searching Bugs):
    Fix the values possible for status queries.
---
 packages/debbugs/debbugs-gnu.el  |    2 +-
 packages/debbugs/debbugs-ug.info |   24 ++++++++++++------------
 packages/debbugs/debbugs-ug.texi |    4 ++--
 packages/debbugs/debbugs.el      |   17 ++++++++---------
 packages/debbugs/debbugs.info    |   13 +++++++------
 packages/debbugs/debbugs.texi    |    7 ++++---
 6 files changed, 34 insertions(+), 33 deletions(-)

diff --git a/packages/debbugs/debbugs-gnu.el b/packages/debbugs/debbugs-gnu.el
index a84083f..3df1117 100644
--- a/packages/debbugs/debbugs-gnu.el
+++ b/packages/debbugs/debbugs-gnu.el
@@ -451,7 +451,7 @@ marked as \"client-side filter\"."
               (completing-read
                (format "Enter status%s: "
                        (if (null phrase) "" " (client-side filter)"))
-               '("pending" "forwarded" "fixed" "done")))
+               '("open" "forwarded" "done")))
              (when (not (zerop (length val1)))
                 (if (null phrase)
                     (add-to-list
diff --git a/packages/debbugs/debbugs-ug.info b/packages/debbugs/debbugs-ug.info
index 11738e3..4a21010 100644
--- a/packages/debbugs/debbugs-ug.info
+++ b/packages/debbugs/debbugs-ug.info
@@ -203,8 +203,8 @@ engine
           Word(s) the subject of the bug report contains.
 
      'status'
-          The status of the bug report.  Valid values are "pending",
-          "forwarded", "fixed" and "done".
+          The status of the bug report.  Valid values are "open",
+          "forwarded" and "done".
 
      It is also possible to apply these commands with an empty search
      phrase.  In this case, the GNU Debbugs server is searched only
@@ -599,15 +599,15 @@ Tag Table:
 Node: Top1097
 Node: Retrieving Bugs2635
 Node: Searching Bugs6362
-Ref: Searching Bugs-Footnote-110520
-Ref: Searching Bugs-Footnote-210608
-Node: Layout10699
-Node: Tabulated Lists11174
-Node: TODO Items14532
-Node: Control Messages15579
-Node: Minor Mode17975
-Node: Command Index18914
-Node: Variable Index19703
-Node: Key Index20422
+Ref: Searching Bugs-Footnote-110508
+Ref: Searching Bugs-Footnote-210596
+Node: Layout10687
+Node: Tabulated Lists11162
+Node: TODO Items14520
+Node: Control Messages15567
+Node: Minor Mode17963
+Node: Command Index18902
+Node: Variable Index19691
+Node: Key Index20410
 
 End Tag Table
diff --git a/packages/debbugs/debbugs-ug.texi b/packages/debbugs/debbugs-ug.texi
index 40057a2..2d5f435 100644
--- a/packages/debbugs/debbugs-ug.texi
+++ b/packages/debbugs/debbugs-ug.texi
@@ -225,8 +225,8 @@ modified.
 Word(s) the subject of the bug report contains.
 
 @item status
-The status of the bug report.  Valid values are "pending",
-"forwarded", "fixed" and "done".
+The status of the bug report.  Valid values are "open", "forwarded"
+and "done".
 @end table
 
 It is also possible to apply these commands with an empty search
diff --git a/packages/debbugs/debbugs.info b/packages/debbugs/debbugs.info
index b05bf77..7763609 100644
--- a/packages/debbugs/debbugs.info
+++ b/packages/debbugs/debbugs.info
@@ -1,4 +1,4 @@
-This is debbugs.info, produced by makeinfo version 6.0 from
+This is debbugs.info, produced by makeinfo version 6.1 from
 debbugs.texi.
 
 Copyright (C) 2011-2016 Free Software Foundation, Inc.
@@ -256,8 +256,8 @@ Debbugs server the list of bug numbers that match a user's 
query.
           do not necessary belong to this package.
 
      ':status'
-          Status of bug.  Valid values are '"done"', '"forwarded"' and
-          '"open"'.
+          Status of bug.  Valid values are '"open"', '"forwarded"' and
+          '"done"'.
 
      ':archive'
           A keyword to filter for bugs which are already archived, or
@@ -320,7 +320,8 @@ and various aspects of relationship with other bug reports.
           (*note Requesting bug numbers::).
 
      'pending'
-          The string '"pending"', '"forwarded"' or '"done"'.
+          The string '"pending"', '"forwarded"', '"fixed"' or
+          '"done"'.
 
      'subject'
           Subject/Title of the bugreport.
@@ -551,7 +552,7 @@ Node: Installation3179
 Node: Configuration4278
 Node: Requesting bug numbers6629
 Node: Requesting bugs statuses11883
-Node: Requesting messages15934
-Node: Requesting user tags18949
+Node: Requesting messages15955
+Node: Requesting user tags18970
 
 End Tag Table
diff --git a/packages/debbugs/debbugs.texi b/packages/debbugs/debbugs.texi
index 0a627d6..d71d866 100644
--- a/packages/debbugs/debbugs.texi
+++ b/packages/debbugs/debbugs.texi
@@ -263,8 +263,8 @@ with the given name.  The bugs are chosen by the value of 
field
 belong to this package.
 
 @item :status
-Status of bug.  Valid values are @code{"done"}, @code{"forwarded"} and
address@hidden"open"}.
+Status of bug.  Valid values are @code{"open"}, @code{"forwarded"} and
address@hidden"done"}.
 
 @item :archive
 A keyword to filter for bugs which are already archived, or not.  Valid
@@ -331,7 +331,8 @@ same as for @code{:tags} in @code{debbugs-get-bugs} 
(@pxref{Requesting
 bug numbers}).
 
 @item pending
-The string @code{"pending"}, @code{"forwarded"} or @code{"done"}.
+The string @code{"pending"}, @code{"forwarded"}, @code{"fixed"} or
address@hidden"done"}.
 
 @item subject
 Subject/Title of the bugreport.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/packages/debbugs/debbugs.el b/packages/debbugs/debbugs.el
index ad51474..8d42f3e 100644
--- a/packages/debbugs/debbugs.el
+++ b/packages/debbugs/debbugs.el
@@ -181,8 +181,8 @@ Valid keywords are:
   the value of field `affects' in bug's status.  The returned bugs
   do not necessary belong to this package.
 
-  :status -- Status of bug.  Valid values are \"pending\",
-  \"forwarded\", \"fixed\" and \"done\".
+  :status -- Status of bug.  Valid values are \"open\",
+  \"forwarded\" and \"done\".
 
   :archive -- A keyword to filter for bugs which are already
   archived, or not.  Valid values are \"0\" (not archived),
@@ -225,8 +225,8 @@ patch:
               (setq vec (vconcat vec (list key val))))
           (error "Wrong %s: %s" key val)))
        (:status
-        ;; Possible values: "pending", "forwarded", "fixed" and "done".
-        (if (string-match "\\`\\(pending\\|forwarded\\|fixed\\|done\\)\\'" val)
+        ;; Possible values: "open", "forwarded" and "done".
+        (if (string-match "\\`\\(open\\|forwarded\\|done\\)\\'" val)
             (setq vec (vconcat vec (list key val)))
           (error "Wrong %s: %s" key val)))
        (:archive
@@ -749,11 +749,10 @@ Examples:
               (setq attr-cond t)
               (if (not (stringp (car elt)))
                   (setq vec (vconcat vec (list key "")))
-                ;; Possible values: "pending", "forwarded", "fixed" and "done".
-                (while  (and (stringp (car elt))
-                             (string-match
-                              "\\`\\(pending\\|forwarded\\|fixed\\|done\\)\\'"
-                              (car elt)))
+                ;; Possible values: "open", "forwarded" and "done".
+                (while (and (stringp (car elt))
+                            (string-match
+                             "\\`\\(open\\|forwarded\\|done\\)\\'" (car elt)))
                   (let ((x (pop elt)))
                     (unless (member x val)
                       (setq val (append val (list x))))))